package com.zaojiao.app.feat.design.viewmodel

import android.util.Log
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.zaojiao.app.feat.design.UiState
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.launch

abstract class BaseViewModel<T>() : ViewModel() {
    private val _stateFlow = MutableStateFlow<UiState<T>>(UiState.Loading)
    val stateFlow: StateFlow<UiState<T>> get() = _stateFlow

    fun initialState(showLoading: Boolean = true) = viewModelScope.launch {
        if (showLoading) {
            setLoading()
        }
        try {
            val result = productState()
            setSuccess(result)
        } catch (e: Throwable) {
            Log.e("BaseViewModel", "${this.javaClass.simpleName}: error", e)
            setFailure(0)
        }
    }

    abstract suspend fun productState(): T

    protected suspend fun setLoading() {
        _stateFlow.emit(UiState.Loading)
    }

    protected suspend fun setSuccess(data: T) {
        _stateFlow.emit(UiState.Success(data))
    }

    protected suspend fun setFailure(code: Int) {
        _stateFlow.emit(UiState.Failure(code))
    }
}